Module instruction

Module instruction 

Structs

InstructionDataInvoke
InvokeInstruction
These are the base accounts additionally Merkle tree and queue accounts are required. These additional accounts are passed as remaining accounts. 1 Merkle tree for each input compressed account one queue and Merkle tree account each for each output compressed account.
InvokeInstructionBumps
NewAddressParams
NewAddressParamsPacked
OutputCompressedAccountWithContext
OutputCompressedAccountWithPackedContext