pub trait AccountsClose<'info>: ToAccountInfos<'info> {
// Required method
fn close(&self, sol_destination: AccountInfo<'info>) -> Result<(), Error>;
}Expand description
The close procedure to initiate garabage collection of an account, allowing one to retrieve the rent exemption.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".